**An application to export Obsidian notes to standard markdown and an html based website.**

See the github repository for the code, to raise issues, and further information: https://github.com/obsidian-html/obsidian-html

You can see the capabilities of this system on the documentation website: https://obsidian-html.github.io/, which is created from an Obsidian vault using only this package.


**What it does**:

The Obsidian notes will be converted to standard markdown output. Then, optionally, html output is created based on the standard markdown. 
It is also possible to input existing standard markdown to just use the markdown to html functionality.

See the docs for more information on configuring the behavior of ObsidianHtml.


**Changelog**:
https://obsidian-html.github.io/Change%20Log.html